#
# spec file for package python-sphinx-tabs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?sle_version} && 0%{?sle_version} <= 150300
%define pythons python3
%endif
%bcond_with      test
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-sphinx-tabs
Version:        3.4.5
Release:        1.3
Summary:        Tabbed views for Sphinx
License:        MIT
URL:            https://github.com/executablebooks/sphinx-tabs
# Use the github tag instead of the pythonhosted.org to get the tests folder
Source:         https://github.com/executablebooks/sphinx-tabs/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pygments
Requires:       python-Sphinx
Requires:       python-docutils
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module pytest-regressions}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sphinx-tabs = %{version}}
%endif
%python_subpackages

%description
Create tabbed content in Sphinx documentation when building HTML.

%prep
%autosetup -p1 -n sphinx-tabs-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# python-rinohtype is not available
%pytest -k 'not test_rinohtype_pdf'
%endif

%if !%{with test}
%files %{python_files}
%{python_sitelib}/sphinx_tabs
%{python_sitelib}/sphinx_tabs-%{version}.dist-info
%endif

%changelog
* Thu Feb  1 2024 Dirk Müller <dmueller@suse.com>
- update to 3.4.5:
  * Removed docutils version pin
* Wed Jan  3 2024 Dirk Müller <dmueller@suse.com>
- require setuptools
* Thu Dec 21 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.4.4:
  * Added
    + Testing for Python 3.11 and 3.12
  * Removed
    + Dependency on unsupported sphinx_testing package
  * Fixed
    + tests for sphinx 7.2
    + slice assignment in update_context(), which was removing JS scripts
    from other sphinx extensions/themes on pages where tabs were not used
- Drop patches sphinx71.patch and sphinx72.patch, included upstream.
- Switch to pyproject macros.
* Mon Oct  9 2023 ecsos <ecsos@opensuse.org>
- Fix build error: patch defined multible times.
* Tue Sep 19 2023 Markéta Machová <mmachova@suse.com>
- Add sphinx71.patch and sphinx72.patch to fix tests with Sphinx 7.2
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Sep 28 2022 Daniel Garcia <daniel.garcia@suse.com>
- Update to v3.4.1
- Add multibuild support to run tests
- Remove sphinx-testing dependecy
* Wed Nov 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Fix building on openSUSE 15.3
* Tue Jun 29 2021 Ondřej Súkup <mimi.vx@gmail.com>
- Initial package
